@@ -162,10 +162,11 @@
          }
 
 
-         eval('if (file_exists($compatibility_sm_path . \'plugins/compatibility/includes/'
+         if (eval('if (file_exists($compatibility_sm_path . \'plugins/compatibility/includes/'
               . $version_string . '/global.php\')) include_once($compatibility_sm_path . \'plugins/compatibility/includes/'
               . $version_string . '/global.php\'); if (compatibility_check_sm_version('
-              . $csv_version_string . ')) return;');
+              . $csv_version_string . ')) return TRUE;'))
+            return;
 
       }
 
@@ -361,7 +362,8 @@ function add_plugin($plugin_name, $args='', $dont_execute=FALSE)
    if (!$dont_execute && !empty($hook_name))
    {
 
-      if (is_array($squirrelmail_plugin_hooks[$hook_name]))
+      if (!empty($squirrelmail_plugin_hooks[$hook_name])
+       && is_array($squirrelmail_plugin_hooks[$hook_name]))
          $new_hook_functions = array_diff($squirrelmail_plugin_hooks[$hook_name],
                                           $original_hook_functions);
       else
